# Copyright (c) 2000-2007, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%global base_name       standard
%global short_name      taglibs-%{base_name}

Name:           jakarta-taglibs-standard
Version:        1.1.2
Release:        %mkrel 15
Epoch:          0
Summary:        An open-source implementation of the JSP Standard Tag Library
License:        ASL 2.0
Group:          Development/Java
URL:            http://jakarta.apache.org/taglibs/
Source0:        http://archive.apache.org/dist/jakarta/taglibs/standard/source/jakarta-taglibs-standard-%{version}-src.tar.gz
Source1:        http://repo1.maven.org/maven2/jstl/jstl/%{version}/jstl-%{version}.pom
Source2:        http://repo1.maven.org/maven2/taglibs/standard/%{version}/standard-%{version}.pom

Patch0:         jakarta-taglibs-standard-1.1.1-build.patch
Patch1:         fix-1.6.0-build.patch
Patch2:         %{name}-jdbc-4.1.patch
# remove relocation use -a parameter with %%add_maven_depmap
# prevent maven/system overflow
Patch3:         jakarta-taglibs-standard-1.1.2-jstl-pom.patch
Patch4:         jakarta-taglibs-standard-1.1.2-standard-pom.patch

Patch5:	        jakarta-taglibs-standard-CVE-2015-0254.patch

BuildArch:      noarch
BuildRequires:  jpackage-utils >= 0:1.5.30
BuildRequires:  ant
BuildRequires:  tomcat-servlet-3.0-api
BuildRequires:  tomcat-jsp-2.2-api
BuildRequires:  java-devel
BuildRequires:  java-javadoc
BuildRequires:  xalan-j2 >= 2.6.0
Requires:       tomcat-servlet-3.0-api
Requires:       tomcat-jsp-2.2-api
Requires:       xalan-j2 >= 2.6.0

Provides:       javax.servlet.jsp.jstl

%description
This package contains Jakarta Taglibs's open-source implementation of the 
JSP Standard Tag Library (JSTL), version 1.1. JSTL is a standard under the
Java Community Process.

%package        javadoc
Summary:        Javadoc for %{name}
Group:          Documentation

%description    javadoc
Javadoc for %{name}.


%prep
%setup -q -n %{name}-%{version}-src
%patch0 -b .orig
%patch1
%patch2
#
rm -fr standard/src/org/apache/taglibs/standard/lang/jstl/test/PageContextImpl.java
rm -fr standard/src/org/apache/taglibs/standard/lang/jstl/test/EvaluationTest.java
cat > build.properties <<EOBP
build.dir=build
dist.dir=dist
servlet24.jar=$(build-classpath tomcat-servlet-3.0-api)
jsp20.jar=$(build-classpath jsp)
jaxp-api.jar=$(build-classpath xalan-j2)
EOBP

cp -p %{SOURCE1} jstl-1.1.2.pom
%patch3 -p0
cp -p %{SOURCE2} standard-1.1.2.pom
%patch4 -p0

%patch5 -p1

%build
ant \
  -Dfinal.name=%{short_name} \
  -Dj2se.javadoc=%{_javadocdir}/java \
  -f standard/build.xml \
  dist


%install
# jars
mkdir -p $RPM_BUILD_ROOT%{_javadir}
cp -p standard/dist/standard/lib/jstl.jar $RPM_BUILD_ROOT%{_javadir}/jakarta-taglibs-core.jar
cp -p standard/dist/standard/lib/standard.jar $RPM_BUILD_ROOT%{_javadir}/jakarta-taglibs-standard.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in jakarta-*; do ln -sf ${jar} `echo $jar| sed "s|jakarta-||g"`; done)

mkdir -p $RPM_BUILD_ROOT%{_mavenpomdir}
install -pm 644 jstl-1.1.2.pom $RPM_BUILD_ROOT%{_mavenpomdir}/JPP-jakarta-taglibs-core.pom
%add_maven_depmap JPP-jakarta-taglibs-core.pom jakarta-taglibs-core.jar -a "javax.servlet:jstl,org.eclipse.jetty.orbit:javax.servlet.jsp.jstl"
install -pm 644 standard-1.1.2.pom $RPM_BUILD_ROOT%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap JPP-%{name}.pom %{name}.jar -a "org.eclipse.jetty.orbit:org.apache.taglibs.standard.glassfish"

# javadoc
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}
cp -pr standard/dist/standard/javadoc/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}

# J2EE API dir
install -d -m 755 %{buildroot}%{_javadir}/javax.servlet.jsp.jstl/
ln -sf ../%{name}.jar %{buildroot}%{_javadir}/javax.servlet.jsp.jstl/
ln -sf ../jakarta-taglibs-core.jar %{buildroot}%{_javadir}/javax.servlet.jsp.jstl/

%files -f .mfiles
%doc LICENSE NOTICE
%doc standard/README_src.txt standard/README_bin.txt standard/dist/doc/doc/standard-doc/*.html
%{_javadir}/taglibs-core.jar
%{_javadir}/taglibs-standard.jar
%{_javadir}/javax.servlet.jsp.jstl/

%files javadoc
%doc LICENSE NOTICE
%doc %{_javadocdir}/%{name}




%changelog
* Tue Mar 31 2015 luigiwalser <luigiwalser> 0:1.1.2-15.mga5
+ Revision: 819470
- fix patch0 to not set source=1.4 and remove patch 6
- add patch from ubuntu to fix CVE-2015-0254
- add patch to not force source=1.4 as it breaks build with this new code

* Wed Oct 15 2014 umeabot <umeabot> 0:1.1.2-14.mga5
+ Revision: 748027
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0:1.1.2-13.mga5
+ Revision: 680620
- Mageia 5 Mass Rebuild

* Wed Jan 08 2014 dmorgan <dmorgan> 0:1.1.2-12.mga4
+ Revision: 565568
- Add javax.servlet.jsp.jstl provides and directory

* Sat Oct 19 2013 umeabot <umeabot> 0:1.1.2-11.mga4
+ Revision: 529859
- Mageia 4 Mass Rebuild

* Sat Jul 13 2013 dmorgan <dmorgan> 0:1.1.2-10.mga4
+ Revision: 453784
- Add depmaps for org.eclipse.jetty.orbit

* Tue Jan 15 2013 dmorgan <dmorgan> 0:1.1.2-9.mga3
+ Revision: 388214
- Rebuild without gcj support

* Mon Jan 14 2013 dmorgan <dmorgan> 0:1.1.2-8.mga3
+ Revision: 387956
- New version

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Apr 30 2011 pterjan <pterjan> 0:1.1.2-7.mga1
+ Revision: 93913
- Update to 1.1.2
- Increase release higher than Mandriva
- Silence setup

* Fri Mar 18 2011 dmorgan <dmorgan> 0:1.1.1-14.mga1
+ Revision: 74325
- Really build without gcj
- Really build without gcj

* Thu Mar 10 2011 dmorgan <dmorgan> 0:1.1.1-13.mga1
+ Revision: 67946
- Fix build
- Fix release
- Fix build

* Thu Feb 03 2011 dmorgan <dmorgan> 0:1.1.1-12.mga1
+ Revision: 46678
- Fix build
- Fix buildroot
- Use fedora spec file
- Do not build with gcj
- Fix buildrequires
- Clean spec file
- Use version 1.1.1 that builds
- Add java-rpmbuild as Buildrequire

  + ahmad <ahmad>
    - imported package jakarta-taglibs-standard


* Sun Sep 16 2007 Anssi Hannula <anssi@mandriva.org> 1.1.2-6mdv2008.0
+ Revision: 87985
- use macros for rebuild-gcj-db
- rebuild to filter out autorequires of GCJ AOT objects
- remove unnecessary Requires(post) on java-gcj-compat

* Sun Sep 09 2007 Pascal Terjan <pterjan@mandriva.org> 0:1.1.2-4mdv2008.0
+ Revision: 82792
- update to new version


* Thu Mar 15 2007 Christiaan Welvaart <spturtle@mandriva.org> 1.1.2-3mdv2007.1
+ Revision: 144224
- rebuild for 2007.1

  + Per Øyvind Karlsen <pkarlsen@mandriva.com>
    - Import jakarta-taglibs-standard

* Thu Aug 24 2006 David Walluck <walluck@mandriva.org> 0:1.1.2-2mdv2007.0
- BuildRequires: jsp

* Fri Nov 11 2005 David Walluck <walluck@mandriva.org> 0:1.1.1-4.2mdk
- aot compile

* Sun May 22 2005 David Walluck <walluck@mandriva.org> 0:1.1.1-4.1mdk
- release

* Sat Oct 23 2004 Fernando Nasser <fnasser@redhat.com> 0:1.1.1-4jpp
- Rebuild to replace incorrect patch file

* Sat Oct 23 2004 Fernando Nasser <fnasser@redhat.com> 0:1.1.1-3jpp
- Remove hack for 1.3 Java that would break building with an IBM SDK.

* Tue Aug 24 2004 Randy Watler <rwatler at finali.com> - 0:1.1.1-2jpp
- Rebuild with ant-1.6.2

* Wed Jul 28 2004 Kaj J. Niemi <kajtzu@fi.basen.net> 0:1.1.1-1jpp
- 1.1.1

